package DateTime::Event::NameDay::france;

use DateTime;

sub nameday_data {
    
    return("france",
           <<"EOF;");
# From:       http://meilleursprenoms.com/site/Fetes/Fetes.htm
# Country:    France
# ReformDate: 1752/12/20

1: # January
  1 *Jour de l'an #'
  2 Basile
  3 Geneviève
  4 Odilon
  5 Edouard
  6 Balthazar, Mélaine, Melchior, Tiffany
  7 Aldric, Cédric, Raymond
  8 Lucien
  9 Alix
 10 Guillaume
 11 Hortense, Pauline
 12 Tatiana
 13 Hilaire, Yvette
 14 Nina
 15 Rachel, Rémi
 16 Marcel
 17 Roseline
 18 Gwendal, Prisca
 19 Marius
 20 Fabien, Sébastien
 21 Agnès
 22 Vincent
 23 Banard
 24 François
 26 Timothé # Pauline
 27 Angèle
 28 Manfred, *Thomas d'Aquin #'
 29 Gildas
 30 Jacinthe, Martine
 31 Marcelle

2: # February
  1 Ella, Siméon
  2 Théophane
  3 Blaise, Nelson, Oscar
  4 Véronique
  5 Agathe
  6 Dorothée, Gaston
  7 Eugénie
  8 Jacqueline
  9 Apolline
 10 Arnaud
 11 Lourdes, *Notre Dame de Lourdes
 12 Félix
 13 Béatrice
 14 Valentin
 15 Claude, Georgina, Jordan
 16 Julienne, Lucile, Onésime
 17 Alexis
 18 Bernadette
 19 Gabin
 20 Aimée
 21 Damien
 22 Isabelle
 23 Lazare
 24 Modeste
 25 Roméo
 26 Nestor
 27 Honorine, Léandre
 28 Romain
 29 Auguste

3: # March
  1 Albin, Aubin, Jonathan
  2 *Charles le Bon
  3 Guénolé, Marin
  4 Casimir
  5 Olivia
  6 Colette
  7 Félicie, Nathan
  8 *Jean de Dieu
  9 Françoise
 10 Vivien
 11 Rosine
 12 Justine, Pol
 13 Rodrigue
 14 Mathilde
 15 Louise
 16 Bénédicte
 17 Patrice, Patrick
 18 Cyrille
 19 Joseph
 20 *Printemps
 21 Axelle, Clémence
 22 Léa
 23 Rébecca, Victorien
 24 Karine # Catherine
 25 Humbert
 26 Larissa
 27 Habib
 28 Gontran
 29 Gladys
 30 Amédée
 31 Benjamin

4: # April
  1 Hugues, Valéry
  2 Sandrine
  3 Richard
  4 Isidore
  5 Irène
  6 Marcellin
  7 Clotaire, *Jean-Baptiste de la Salle
  8 Julie
  9 Gautier
 10 Fulbert
 11 Stanislas
 12 Jules
 13 Ida
 14 Ludivine, Maxime
 15 César
 16 Rameaux
 17 Anicet
 18 Parfait
 19 Emma
 20 Odette, Théotime
 21 Anselme
 22 Alexandre
 23 Georges
 24 Fidèle
 25 Marc
 26 Alida
 27 Zita
 28 Valérie
 29 *Catherine de Sienne
 30 Robert

5: # May
  1 Brieuc, Florine, Jérémie, Tamara
  2 Boris, Zoé
  3 Ewen, Philippe # Jacques
  4 Florian, Sylvain
  5 Judith
  6 Marien, Prudence
  7 Domitille, Gisèle
  8 Désiré
  9 Pacôme
 10 Solange
 11 Estelle, Mayeul
 12 Achille
 13 Maël, Orlane, Rolande
 14 Aglaé, Matthias
 15 Denise
 16 Brendan, Honoré
 17 Pascal
 18 Eric
 19 Célestin, Erwan, Yves
 20 Bernardin
 21 Constantin
 22 Emile, Quitterie, Rita
 23 Didier
 24 Donatien
 25 Sophie
 26 Bérenger
 27 Augustin
 28 Germain
 29 Aymar, Géraldine, Maximin
 30 Ferdinand, Jeanne, Lorraine
 31 Pétronille

6: # June
  1 Justin, Ronan
  2 Blandine
  3 Kévin
  4 Clotilde
  5 Igor
  6 Norbert
  7 Gilbert
  8 Médard
  9 Diane
 10 Landry
 11 Barnabé
 12 Guy
 13 *Antoine de Padoue
 14 Elisée, Valère
 15 Germaine
 16 François-Régis, Régis
 17 Hervé
 18 Léonce
 19 Gervais, Romuald
 20 Silvère
 21 Eté
 22 Alban
 23 Audrey
 24 Jean-Baptiste
 25 Aliénor, Eléonore, Prosper, Salomon
 26 Anthelme
 27 Fernand
 28 Irénée
 29 Paul, Pierre
 30 Adolphe, Martial

7: # July
  1 Aaron, Esther, Goulwen, Thierry
  2 Martinien
  3 Thomas
  4 Florent
  5 Antoine
  6 Mariette, Nolwen
  7 Raoul
  8 Edgar, Killian, Priscillia, Thibault
  9 Amandine, Hermine, Iphigénie, Marianne
 10 Ulrich
 11 Benoit, Olga, Yolande
 12 Jason, Olivier
 13 Enzo, Eugène, Henri, Joël
 14 Camille
 15 Donald, Vladimir
 16 Elvire
 17 Arlette, Charlotte, Marcelline
 18 Frédéric
 19 Arsène, Micheline
 20 Elie, Marina
 21 Rodolphe, Térence, Victor
 22 Madeleine, Wandrille
 23 Brigitte
 24 Christine, Ségolène
 25 Jacques, Valentine
 26 Anne, Hannah, Joachin
 27 Aurèle, Nathalie
 28 Samson
 29 Beatrix, Loup, Marthe
 30 Juliette
 31 Ignace, *Ignace de Loyola

8: # August
  1 Alphonse
  2 Julien, *Julien Eymard
  3 Lydie
  4 Vianney
  5 Abel
  6 *Transfiguration
  7 Gaétan
  8 Dominique
  9 Amour
 10 Laurent
 11 Claire, Gilberte, Suzanne
 12 Clarisse
 13 Hippolyte
 14 Evrard
 15 Alfred, Marie
 16 Armel, Roch
 17 Hyacinthe
 18 Hélène, Laétitia
 19 *Jean Eudes
 20 Bernard, Samuel
 21 Christophe, Grâce, Ombeline
 22 Fabrice
 23 Rose, *Rose de Lima
 24 Barthélémy
 25 Louis
 26 Natacha
 27 Monique
 28 Elouan # Augustin
 29 Médéric, Sabine
 30 Fiacre
 31 Aristide

9: # September
  1 Gilles, Jossué
  2 Ingrid
  3 Grégoire
  4 Iris, Moïse, Rosalie
  5 Raïssa
  6 Bertrand, Eva
  7 Reine
  8 Adrien, Béline, Nativité
  9 Alain, Omer
 10 Inès
 11 Adelphe, Glenn, Vinciane
 12 Apollinaire
 13 Aimé
 14 *Croix Glorieuse
 15 Dolores, Roland
 16 Edith
 17 Hildegarde, Lambert, Renaud
 18 Nadège, Véra
 19 Emilie
 20 Davy
 21 Déborah, Jonas, Matthieu, Mélissa
 22 Maurice
 23 Faustine
 24 Thècle
 25 Hermann
 26 Côme # Damien
 27 *Vincent de Paul
 28 Venceslas
 29 Gabriel, Michel, Raphaël
 30 Jérôme

10: # October
  1 Ariel, Mélodie, Muriel, *Thérèse de l'Enfant Jésus #'
  2 Léger, Ruth
  3 Gérard, Sybille
  4 Aure, Bérénice, Frank, Orianne, Sarah, *François d'Assise #'
  5 Camélia, Capucine, Daphne, Eglantin, Fleur, Placide
  6 Bruno
  7 Gustave, Serge
  8 Pélagie, Thaïs
  9 Denis
 10 Ghislain, Virgile
 11 Firmin
 12 Edwin, Séraphin, Wilfried
 13 Géraud
 14 Céleste, Gwendoline, Juste
 15 Thérèse, *Thérèse d'Avila #'
 16 Edwige
 17 Baudoin, Solène
 18 Luc
 19 Cléo, René
 20 Adeline, Aline
 21 Céline, Ursule
 22 Elodie, Salomé, Sara
 23 Simon, *Jean de Capistran
 24 Florentin
 25 Crépin
 26 Dimitri
 27 Emeline
 28 Jude
 29 Narcisse
 30 Bienvenue, Maéva
 31 Quentin

11: # November
  1 Toussaint
  2 Défunts
  3 Gwenaël, Hubert
  4 Aymeric, Charles, Jessé
  5 Sylvie, Zacharie
  6 Bertille, Léonard
  7 Carine
  8 Dora, Geoffroy
  9 Maturin, Théodore
 10 Léon, Noé
 11 Martin, Vérane
 12 Christian
 13 Brice
 14 Sidoine
 15 Albert, Arthur, Léopold, Malo, Victoire
 16 Gertrude, Marguerite, Mégane
 17 Elisabeth, Elise, Hilda
 18 Aude
 19 Tanguy
 20 Edmond, Octave
 21 *Présence de Marie
 22 Cécile
 23 Clément
 24 Flora
 25 Catherine
 26 Delphine
 27 Séverin
 28 *Jacques de la Marche
 29 Saturnin
 30 André, Tugdual

12: # December
  1 Florence
  2 Viviane
  3 Xavier
  4 Barbara
  5 Gérald # Gérard
  6 Nicolas
  7 Ambroise
  8 *Immaculée Conception
  9 *Pierre Fourier
 10 Eulaire, Romaric
 11 Daniel
 12 Chantal
 13 Jocelyn, Lucie
 14 Odile
 15 Ninon
 16 Alice
 17 Adélaïde, Gaël, Judicaël, Olympe
 18 Briac, Gatien
 19 Urbain
 20 Isaac, Jacob, Théophile
 21 * Pierre Canis
 22 Françoise-Xavière, Gratien
 23 Armand
 24 Adèle
 25 Manuel
 26 Etienne
 27 Fabiola, Jean
 28 Gaspard
 29 David
 30 Roger
 31 Colombe, Sylvestre
EOF;
}

1;
